@@ -28,16 +28,15 @@
 // PKG_ADD: autoload ("zmq_getsockopt", "zeromq.oct");
 DEFUN_DLD (zmq_getsockopt, args, nargout,
         "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} @var{value} =  zmq_getsockopt (@var{sock}, @var{optionid})\n \
+@deftypefn {} {@var{value} =} zmq_getsockopt (@var{sock}, @var{optionid})\n \
 \n\
 Get the current value of an option.\n \
 \n \
+@subsubheading Inputs\n \
 @var{sock} - the socket to connect.\n \
 \n \
 @var{optionid} - the setsockopt option to set.\n \
 \n \
-@var{value} - the value set for the option, or [].\n \
-\n \
 Valid @var{optionid}s are:\n \
 @table @asis\n \
 @item @code{ZMQ_RCVMORE}\n \
@@ -52,8 +51,14 @@ The returned value is a bit mask that may contain the following set values:\n \
 @item @code{ZMQ_POLLIN} set when at least one message is available to read and zmq_recv will not block.\n \
 @item @code{ZMQ_POLLOUT} set when at least one message can be written without zmq_send blocking.\n \
 @end itemize\n \
-@item @code{ZMQ_IDENTITY}\n \
+@item @code{ZMQ_IDENTITY} or @code{ZMQ_ROUTING_ID}\n \
 Get the socket identity value\n \
+@item @code{ZMQ_RATE}\n \
+Get the multicast data rate\n \
+@item @code{ZMQ_PRIORITY}\n \
+Get socket priority (linux only)\n \
+@item @code{ZMQ_BACKLOG}\n \
+Get length of queue for pending connections\n \
 @item @code{ZMQ_LAST_ENDPOINT}\n \
 Get the last endpoint the socket was connected to\n \
 @item @code{ZMQ_CONNECT_TIMEOUT}\n \
@@ -86,6 +91,9 @@ Get the name of the gssapi service principal (string)\n \
 Get the security mechanism (ZMQ_NULL, ZMQ_PLAIN, ZMQ_CURVE, ZMQ_GSSAPI)\n \
 @end table\n \
 \n \
+@subsubheading Outputs\n \
+@var{value} - the value set for the option, or [].\n \
+\n \
 @seealso{zmq_socket, zmq_setsockopt}\n \
 @end deftypefn")
 {
@@ -189,7 +197,11 @@ Get the security mechanism (ZMQ_NULL, ZMQ_PLAIN, ZMQ_CURVE, ZMQ_GSSAPI)\n \
       ret = octave_value (value);
     }
     break;
+#ifdef ZMQ_ROUTING_ID
+ case ZMQ_ROUTING_ID:
+#else
  case ZMQ_IDENTITY:
+#endif
     {
       uint8_t value[256];
       size_t sz = sizeof (value);
@@ -475,6 +487,45 @@ Get the security mechanism (ZMQ_NULL, ZMQ_PLAIN, ZMQ_CURVE, ZMQ_GSSAPI)\n \
     }
     break;
 #endif 
+#ifdef ZMQ_PRIORITY
+  case ZMQ_PRIORITY:
+    {
+      int value;
+      size_t sz = sizeof (value);
+
+      if (! sock->getsockopt (opt, &value, &sz))
+        error ("zeromq: failed getsockopt");
+
+      ret = octave_value (value);
+    }
+    break;
+#endif 
+#ifdef ZMQ_RATE
+  case ZMQ_RATE:
+    {
+      int value;
+      size_t sz = sizeof (value);
+
+      if (! sock->getsockopt (opt, &value, &sz))
+        error ("zeromq: failed getsockopt");
+
+      ret = octave_value (value);
+    }
+    break;
+#endif 
+#ifdef ZMQ_BACKLOG
+  case ZMQ_BACKLOG:
+    {
+      int value;
+      size_t sz = sizeof (value);
+
+      if (! sock->getsockopt (opt, &value, &sz))
+        error ("zeromq: failed getsockopt");
+
+      ret = octave_value (value);
+    }
+    break;
+#endif 
 
   default:
     error ("zeromq: invalid getsockopt value %d", opt);
