@@ -27,10 +27,11 @@
 // PKG_ADD: autoload ("zmq_has", "zeromq.oct");
 DEFUN_DLD (zmq_has, args, nargout,
         "-*- texinfo -*-\n \
-@deftypefn {Loadable Function} {@var{yesno} =} zmq_has (@var{feature})\n \
+@deftypefn {} {@var{yesno} =} zmq_has (@var{feature})\n \
 \n\
 Check if the zmq library supports a given feature.\n \
 \n \
+@subsubheading Inputs\n \
 @var{feature} is the name of feature to check.\n \
 \n \
 Currently known features are:\n \
@@ -51,7 +52,8 @@ library supports the GSSAPI security mechanism\n \
 library was built with the draft API.\n \
 @end table\n \
 \n \
-Returns the @var{yesno}, set to true if the feature is available, otherwise false. \
+@subsubheading Outputs\n \
+@var{yesno} - set to true if the feature is available, otherwise false. \
 \n \
 @end deftypefn")
 {
