@@ -35,11 +35,12 @@
 // PKG_ADD: autoload ("zmq_poll", "zeromq.oct");
 DEFUN_DLD (zmq_poll, args, nargout,
         "-*- texinfo -*-\n \
-@deftypefn {Loadable Function} @var{havedata} =  zmq_poll (@var{sock}, @var{timeout})\n \
-@deftypefnx {Loadable Function} @var{indexlist} =  zmq_poll (@var{socklist}, @var{timeout})\n \
+@deftypefn {} {@var{havedata} =} zmq_poll (@var{sock}, @var{timeout})\n \
+@deftypefnx {} {@var{indexlist} =} zmq_poll (@var{socklist}, @var{timeout})\n \
 \n\
 Wait up to timeout time for received data on socket.\n \
 \n \
+@subsubheading Inputs\n \
 @var{sock} - the socket to wait on.\n \
 \n \
 @var{socklist} - the array of sockets to wait on.\n \
@@ -47,6 +48,7 @@ Wait up to timeout time for received data on socket.\n \
 @var{timeout} - timeout time in milliseconds.\n \
 A value of 0 will return without waiting. A value of -1 will wait until there is data.\n \
 \n \
+@subsubheading Outputs\n \
 @var{havedata} - value of 1 if have data.\n \
 \n \
 @var{indexlist} - cell array of indexes to sockets that have data.\n \
