@@ -27,11 +27,14 @@
 // PKG_ADD: autoload ("zmq_strerror", "zeromq.oct");
 DEFUN_DLD (zmq_strerror, args, nargout,
         "-*- texinfo -*-\n \
-@deftypefn {Loadable Function} @var{errorstr} =  zmq_strerror ()\n \
+@deftypefn {} {@var{errorstr} =} zmq_strerror ()\n \
 \n\
 Get the last error from zeromq.\n \
 \n \
-@var{errorstr} is a string representation of the last error \
+@subsubheading Inputs\n \
+None\n \
+@subsubheading Outputs\n \
+@var{errorstr} - a string representation of the last error \
 \n \
 @end deftypefn")
 {
