@@ -29,12 +29,14 @@
 // PKG_ADD: autoload ("zmq_version", "zeromq.oct");
 DEFUN_DLD (zmq_version, args, nargout,
         "-*- texinfo -*-\n \
-@deftypefn {Loadable Function} [@var{major}, @var{minor}, @var{patch}] =  \
- zmq_version ()\n \
+@deftypefn {} {[@var{major}, @var{minor}, @var{patch}] =} zmq_version ()\n \
 \n\
 Get the ZeroMQ library version.\n \
 \n \
-Returns the @var{major}, @var{minor} and @var{patch} level version of the ZeroMQ library. \
+@subsubheading Inputs\n \
+None\n \
+@subsubheading Outputs\n \
+@var{major}, @var{minor} @var{patch} - version of the ZeroMQ library. \
 \n \
 @end deftypefn")
 {
